@@ -17,7 +17,7 @@ def Flider():
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
-            data = pkgutil.get_data(__name__, 'read_files/' + read_names[i])
+            data = pkgutil.get_data(__name__, read_names[i])
             write_file = open(completeName, 'w')
             write_file.write(data)
             write_file.close()
